# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.7.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from tb_rest_client.api_client import ApiClient


class GroupPermissionControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_group_permission_using_delete(self, group_permission_id, **kwargs):  # noqa: E501
        """Delete group permission (deleteGroupPermission)  # noqa: E501

        Deletes the group permission. Referencing non-existing group permission Id will cause an error.   Security check is performed to verify that the user has 'DELETE' permission for the entity (entities).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_group_permission_using_delete(group_permission_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_permission_id: A string value representing the group permission id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_group_permission_using_delete_with_http_info(group_permission_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_group_permission_using_delete_with_http_info(group_permission_id, **kwargs)  # noqa: E501
            return data

    def delete_group_permission_using_delete_with_http_info(self, group_permission_id, **kwargs):  # noqa: E501
        """Delete group permission (deleteGroupPermission)  # noqa: E501

        Deletes the group permission. Referencing non-existing group permission Id will cause an error.   Security check is performed to verify that the user has 'DELETE' permission for the entity (entities).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_group_permission_using_delete_with_http_info(group_permission_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_permission_id: A string value representing the group permission id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_permission_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_group_permission_using_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_permission_id' is set
        if ('group_permission_id' not in params or
                params['group_permission_id'] is None):
            raise ValueError("Missing the required parameter `group_permission_id` when calling `delete_group_permission_using_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_permission_id' in params:
            path_params['groupPermissionId'] = params['group_permission_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/groupPermission/{groupPermissionId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_entity_group_permissions_using_get(self, entity_group_id, **kwargs):  # noqa: E501
        """Get group permissions by Entity Group Id (getEntityGroupPermissions)  # noqa: E501

        Returns a list of group permission objects that is assigned for the specified Entity Group Id. Group permission entity represents list of allowed operations for certain User Group to perform against certain Entity Group. Basically, this entity wires three other entities:    * Role that defines set of allowed operations;  * User Group that defines set of users who may perform the operations;   * Entity Group that defines set of entities which will be accessible to users;   Group Permission Info object extends the Group Permissions with the full information about Role and User and/or Entity Groups.    Security check is performed to verify that the user has 'READ' permission for the entity (entities).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_entity_group_permissions_using_get(entity_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str entity_group_id: A string value representing the Entity Group Id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: list[GroupPermissionInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_entity_group_permissions_using_get_with_http_info(entity_group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_entity_group_permissions_using_get_with_http_info(entity_group_id, **kwargs)  # noqa: E501
            return data

    def get_entity_group_permissions_using_get_with_http_info(self, entity_group_id, **kwargs):  # noqa: E501
        """Get group permissions by Entity Group Id (getEntityGroupPermissions)  # noqa: E501

        Returns a list of group permission objects that is assigned for the specified Entity Group Id. Group permission entity represents list of allowed operations for certain User Group to perform against certain Entity Group. Basically, this entity wires three other entities:    * Role that defines set of allowed operations;  * User Group that defines set of users who may perform the operations;   * Entity Group that defines set of entities which will be accessible to users;   Group Permission Info object extends the Group Permissions with the full information about Role and User and/or Entity Groups.    Security check is performed to verify that the user has 'READ' permission for the entity (entities).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_entity_group_permissions_using_get_with_http_info(entity_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str entity_group_id: A string value representing the Entity Group Id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: list[GroupPermissionInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['entity_group_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_entity_group_permissions_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'entity_group_id' is set
        if ('entity_group_id' not in params or
                params['entity_group_id'] is None):
            raise ValueError("Missing the required parameter `entity_group_id` when calling `get_entity_group_permissions_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'entity_group_id' in params:
            path_params['entityGroupId'] = params['entity_group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/entityGroup/{entityGroupId}/groupPermissions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[GroupPermissionInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_group_permission_by_id_using_get(self, group_permission_id, **kwargs):  # noqa: E501
        """Get Group Permission (getGroupPermissionById)  # noqa: E501

        Fetch the Group Permission object based on the provided Group Permission Id. Group permission entity represents list of allowed operations for certain User Group to perform against certain Entity Group. Basically, this entity wires three other entities:    * Role that defines set of allowed operations;  * User Group that defines set of users who may perform the operations;   * Entity Group that defines set of entities which will be accessible to users;   Security check is performed to verify that the user has 'READ' permission for the entity (entities).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_group_permission_by_id_using_get(group_permission_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_permission_id: A string value representing the group permission id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: GroupPermission
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_group_permission_by_id_using_get_with_http_info(group_permission_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_group_permission_by_id_using_get_with_http_info(group_permission_id, **kwargs)  # noqa: E501
            return data

    def get_group_permission_by_id_using_get_with_http_info(self, group_permission_id, **kwargs):  # noqa: E501
        """Get Group Permission (getGroupPermissionById)  # noqa: E501

        Fetch the Group Permission object based on the provided Group Permission Id. Group permission entity represents list of allowed operations for certain User Group to perform against certain Entity Group. Basically, this entity wires three other entities:    * Role that defines set of allowed operations;  * User Group that defines set of users who may perform the operations;   * Entity Group that defines set of entities which will be accessible to users;   Security check is performed to verify that the user has 'READ' permission for the entity (entities).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_group_permission_by_id_using_get_with_http_info(group_permission_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_permission_id: A string value representing the group permission id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: GroupPermission
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_permission_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_group_permission_by_id_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_permission_id' is set
        if ('group_permission_id' not in params or
                params['group_permission_id'] is None):
            raise ValueError("Missing the required parameter `group_permission_id` when calling `get_group_permission_by_id_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_permission_id' in params:
            path_params['groupPermissionId'] = params['group_permission_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/groupPermission/{groupPermissionId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GroupPermission',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_group_permission_info_by_id_using_get(self, group_permission_id, is_user_group, **kwargs):  # noqa: E501
        """Get Group Permission Info (getGroupPermissionInfoById)  # noqa: E501

        Fetch the Group Permission Info object based on the provided Group Permission Id and the flag that controls what additional information to load: User or Entity Group. Group permission entity represents list of allowed operations for certain User Group to perform against certain Entity Group. Basically, this entity wires three other entities:    * Role that defines set of allowed operations;  * User Group that defines set of users who may perform the operations;   * Entity Group that defines set of entities which will be accessible to users;   Group Permission Info object extends the Group Permissions with the full information about Role and User and/or Entity Groups.  Security check is performed to verify that the user has 'READ' permission for the entity (entities).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_group_permission_info_by_id_using_get(group_permission_id, is_user_group, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_permission_id: A string value representing the group permission id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :param bool is_user_group: Load additional information about User('true') or Entity Group('false). (required)
        :return: GroupPermissionInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_group_permission_info_by_id_using_get_with_http_info(group_permission_id, is_user_group, **kwargs)  # noqa: E501
        else:
            (data) = self.get_group_permission_info_by_id_using_get_with_http_info(group_permission_id, is_user_group, **kwargs)  # noqa: E501
            return data

    def get_group_permission_info_by_id_using_get_with_http_info(self, group_permission_id, is_user_group, **kwargs):  # noqa: E501
        """Get Group Permission Info (getGroupPermissionInfoById)  # noqa: E501

        Fetch the Group Permission Info object based on the provided Group Permission Id and the flag that controls what additional information to load: User or Entity Group. Group permission entity represents list of allowed operations for certain User Group to perform against certain Entity Group. Basically, this entity wires three other entities:    * Role that defines set of allowed operations;  * User Group that defines set of users who may perform the operations;   * Entity Group that defines set of entities which will be accessible to users;   Group Permission Info object extends the Group Permissions with the full information about Role and User and/or Entity Groups.  Security check is performed to verify that the user has 'READ' permission for the entity (entities).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_group_permission_info_by_id_using_get_with_http_info(group_permission_id, is_user_group, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_permission_id: A string value representing the group permission id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :param bool is_user_group: Load additional information about User('true') or Entity Group('false). (required)
        :return: GroupPermissionInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_permission_id', 'is_user_group']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_group_permission_info_by_id_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_permission_id' is set
        if ('group_permission_id' not in params or
                params['group_permission_id'] is None):
            raise ValueError("Missing the required parameter `group_permission_id` when calling `get_group_permission_info_by_id_using_get`")  # noqa: E501
        # verify the required parameter 'is_user_group' is set
        if ('is_user_group' not in params or
                params['is_user_group'] is None):
            raise ValueError("Missing the required parameter `is_user_group` when calling `get_group_permission_info_by_id_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_permission_id' in params:
            path_params['groupPermissionId'] = params['group_permission_id']  # noqa: E501

        query_params = []
        if 'is_user_group' in params:
            query_params.append(('isUserGroup', params['is_user_group']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/groupPermission/info/{groupPermissionId}{?isUserGroup}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GroupPermissionInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user_group_permissions_using_get(self, user_group_id, **kwargs):  # noqa: E501
        """Get group permissions by User Group Id (getUserGroupPermissions)  # noqa: E501

        Returns a list of group permission objects that belongs to specified User Group Id. Group permission entity represents list of allowed operations for certain User Group to perform against certain Entity Group. Basically, this entity wires three other entities:    * Role that defines set of allowed operations;  * User Group that defines set of users who may perform the operations;   * Entity Group that defines set of entities which will be accessible to users;   Group Permission Info object extends the Group Permissions with the full information about Role and User and/or Entity Groups.    Security check is performed to verify that the user has 'READ' permission for the entity (entities).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_group_permissions_using_get(user_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: A string value representing the Entity Group Id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: list[GroupPermissionInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_user_group_permissions_using_get_with_http_info(user_group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_user_group_permissions_using_get_with_http_info(user_group_id, **kwargs)  # noqa: E501
            return data

    def get_user_group_permissions_using_get_with_http_info(self, user_group_id, **kwargs):  # noqa: E501
        """Get group permissions by User Group Id (getUserGroupPermissions)  # noqa: E501

        Returns a list of group permission objects that belongs to specified User Group Id. Group permission entity represents list of allowed operations for certain User Group to perform against certain Entity Group. Basically, this entity wires three other entities:    * Role that defines set of allowed operations;  * User Group that defines set of users who may perform the operations;   * Entity Group that defines set of entities which will be accessible to users;   Group Permission Info object extends the Group Permissions with the full information about Role and User and/or Entity Groups.    Security check is performed to verify that the user has 'READ' permission for the entity (entities).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_group_permissions_using_get_with_http_info(user_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: A string value representing the Entity Group Id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: list[GroupPermissionInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_group_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user_group_permissions_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_group_id' is set
        if ('user_group_id' not in params or
                params['user_group_id'] is None):
            raise ValueError("Missing the required parameter `user_group_id` when calling `get_user_group_permissions_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_group_id' in params:
            path_params['userGroupId'] = params['user_group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/userGroup/{userGroupId}/groupPermissions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[GroupPermissionInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def load_user_group_permission_infos_using_post(self, **kwargs):  # noqa: E501
        """Load User Group Permissions (loadUserGroupPermissionInfos)  # noqa: E501

        Enrich a list of group permission objects with the information about Role, User and Entity Groups. Group permission entity represents list of allowed operations for certain User Group to perform against certain Entity Group. Basically, this entity wires three other entities:    * Role that defines set of allowed operations;  * User Group that defines set of users who may perform the operations;   * Entity Group that defines set of entities which will be accessible to users;   Group Permission Info object extends the Group Permissions with the full information about Role and User and/or Entity Groups.    Security check is performed to verify that the user has 'READ' permission for the entity (entities).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.load_user_group_permission_infos_using_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[GroupPermission] body:
        :return: list[GroupPermissionInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.load_user_group_permission_infos_using_post_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.load_user_group_permission_infos_using_post_with_http_info(**kwargs)  # noqa: E501
            return data

    def load_user_group_permission_infos_using_post_with_http_info(self, **kwargs):  # noqa: E501
        """Load User Group Permissions (loadUserGroupPermissionInfos)  # noqa: E501

        Enrich a list of group permission objects with the information about Role, User and Entity Groups. Group permission entity represents list of allowed operations for certain User Group to perform against certain Entity Group. Basically, this entity wires three other entities:    * Role that defines set of allowed operations;  * User Group that defines set of users who may perform the operations;   * Entity Group that defines set of entities which will be accessible to users;   Group Permission Info object extends the Group Permissions with the full information about Role and User and/or Entity Groups.    Security check is performed to verify that the user has 'READ' permission for the entity (entities).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.load_user_group_permission_infos_using_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[GroupPermission] body:
        :return: list[GroupPermissionInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method load_user_group_permission_infos_using_post" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/userGroup/groupPermissions/info', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[GroupPermissionInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def save_group_permission_using_post(self, **kwargs):  # noqa: E501
        """Create Or Update Group Permission (saveGroupPermission)  # noqa: E501

        Creates or Updates the Group Permission. When creating group permission, platform generates Group Permission Id as [time-based UUID](https://en.wikipedia.org/wiki/Universally_unique_identifier#Version_1_(date-time_and_MAC_address)). The newly created Group Permission id will be present in the response. Specify existing Group Permission id to update the permission. Referencing non-existing Group Permission Id will cause 'Not Found' error.  Group permission entity represents list of allowed operations for certain User Group to perform against certain Entity Group. Basically, this entity wires three other entities:    * Role that defines set of allowed operations;  * User Group that defines set of users who may perform the operations;   * Entity Group that defines set of entities which will be accessible to users;   Security check is performed to verify that the user has 'WRITE' permission for the entity (entities).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.save_group_permission_using_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GroupPermission body:
        :return: GroupPermission
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.save_group_permission_using_post_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.save_group_permission_using_post_with_http_info(**kwargs)  # noqa: E501
            return data

    def save_group_permission_using_post_with_http_info(self, **kwargs):  # noqa: E501
        """Create Or Update Group Permission (saveGroupPermission)  # noqa: E501

        Creates or Updates the Group Permission. When creating group permission, platform generates Group Permission Id as [time-based UUID](https://en.wikipedia.org/wiki/Universally_unique_identifier#Version_1_(date-time_and_MAC_address)). The newly created Group Permission id will be present in the response. Specify existing Group Permission id to update the permission. Referencing non-existing Group Permission Id will cause 'Not Found' error.  Group permission entity represents list of allowed operations for certain User Group to perform against certain Entity Group. Basically, this entity wires three other entities:    * Role that defines set of allowed operations;  * User Group that defines set of users who may perform the operations;   * Entity Group that defines set of entities which will be accessible to users;   Security check is performed to verify that the user has 'WRITE' permission for the entity (entities).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.save_group_permission_using_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GroupPermission body:
        :return: GroupPermission
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method save_group_permission_using_post" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/groupPermission', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GroupPermission',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.7.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from tb_rest_client.api_client import ApiClient


class AuditLogControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_audit_logs_by_customer_id_using_get(self, customer_id, page_size, page, **kwargs):  # noqa: E501
        """Get audit logs by customer id (getAuditLogsByCustomerId)  # noqa: E501

        Returns a page of audit logs related to the targeted customer entities (devices, assets, etc.), and users actions (login, logout, etc.) that belong to this customer. You can specify parameters to filter the results. The result is wrapped with PageData object that allows you to iterate over result set using pagination. See the 'Model' tab of the Response Class for more details.   Available for users with 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_audit_logs_by_customer_id_using_get(customer_id, page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str customer_id: A string value representing the customer id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :param int page_size: Maximum amount of entities in a one page (required)
        :param int page: Sequence number of page starting from 0 (required)
        :param str text_search: The case insensitive 'substring' filter based on one of the next properties: entityType, entityName, userName, actionType, actionStatus.
        :param str sort_property: Property of audit log to sort by. See the 'Model' tab of the Response Class for more details. Note: entityType sort property is not defined in the AuditLog class, however, it can be used to sort audit logs by types of entities that were logged.
        :param str sort_order: Sort order. ASC (ASCENDING) or DESC (DESCENDING)
        :param int start_time: The start timestamp in milliseconds of the search time range over the AuditLog class field: 'createdTime'.
        :param int end_time: The end timestamp in milliseconds of the search time range over the AuditLog class field: 'createdTime'.
        :param str action_types: A String value representing comma-separated list of action types. This parameter is optional, but it can be used to filter results to fetch only audit logs of specific action types. For example, 'LOGIN', 'LOGOUT'. See the 'Model' tab of the Response Class for more details.
        :return: PageDataAuditLog
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_audit_logs_by_customer_id_using_get_with_http_info(customer_id, page_size, page, **kwargs)  # noqa: E501
        else:
            (data) = self.get_audit_logs_by_customer_id_using_get_with_http_info(customer_id, page_size, page, **kwargs)  # noqa: E501
            return data

    def get_audit_logs_by_customer_id_using_get_with_http_info(self, customer_id, page_size, page, **kwargs):  # noqa: E501
        """Get audit logs by customer id (getAuditLogsByCustomerId)  # noqa: E501

        Returns a page of audit logs related to the targeted customer entities (devices, assets, etc.), and users actions (login, logout, etc.) that belong to this customer. You can specify parameters to filter the results. The result is wrapped with PageData object that allows you to iterate over result set using pagination. See the 'Model' tab of the Response Class for more details.   Available for users with 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_audit_logs_by_customer_id_using_get_with_http_info(customer_id, page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str customer_id: A string value representing the customer id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :param int page_size: Maximum amount of entities in a one page (required)
        :param int page: Sequence number of page starting from 0 (required)
        :param str text_search: The case insensitive 'substring' filter based on one of the next properties: entityType, entityName, userName, actionType, actionStatus.
        :param str sort_property: Property of audit log to sort by. See the 'Model' tab of the Response Class for more details. Note: entityType sort property is not defined in the AuditLog class, however, it can be used to sort audit logs by types of entities that were logged.
        :param str sort_order: Sort order. ASC (ASCENDING) or DESC (DESCENDING)
        :param int start_time: The start timestamp in milliseconds of the search time range over the AuditLog class field: 'createdTime'.
        :param int end_time: The end timestamp in milliseconds of the search time range over the AuditLog class field: 'createdTime'.
        :param str action_types: A String value representing comma-separated list of action types. This parameter is optional, but it can be used to filter results to fetch only audit logs of specific action types. For example, 'LOGIN', 'LOGOUT'. See the 'Model' tab of the Response Class for more details.
        :return: PageDataAuditLog
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['customer_id', 'page_size', 'page', 'text_search', 'sort_property', 'sort_order', 'start_time', 'end_time', 'action_types']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_audit_logs_by_customer_id_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'customer_id' is set
        if ('customer_id' not in params or
                params['customer_id'] is None):
            raise ValueError("Missing the required parameter `customer_id` when calling `get_audit_logs_by_customer_id_using_get`")  # noqa: E501
        # verify the required parameter 'page_size' is set
        if ('page_size' not in params or
                params['page_size'] is None):
            raise ValueError("Missing the required parameter `page_size` when calling `get_audit_logs_by_customer_id_using_get`")  # noqa: E501
        # verify the required parameter 'page' is set
        if ('page' not in params or
                params['page'] is None):
            raise ValueError("Missing the required parameter `page` when calling `get_audit_logs_by_customer_id_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'customer_id' in params:
            path_params['customerId'] = params['customer_id']  # noqa: E501

        query_params = []
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'text_search' in params:
            query_params.append(('textSearch', params['text_search']))  # noqa: E501
        if 'sort_property' in params:
            query_params.append(('sortProperty', params['sort_property']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('sortOrder', params['sort_order']))  # noqa: E501
        if 'start_time' in params:
            query_params.append(('startTime', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('endTime', params['end_time']))  # noqa: E501
        if 'action_types' in params:
            query_params.append(('actionTypes', params['action_types']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/audit/logs/customer/{customerId}{?actionTypes,endTime,page,pageSize,sortOrder,sortProperty,startTime,textSearch}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageDataAuditLog',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_audit_logs_by_entity_id_using_get(self, entity_type, entity_id, page_size, page, **kwargs):  # noqa: E501
        """Get audit logs by entity id (getAuditLogsByEntityId)  # noqa: E501

        Returns a page of audit logs related to the actions on the targeted entity. Basically, this API call is used to get the full lifecycle of some specific entity. For example to see when a device was created, updated, assigned to some customer, or even deleted from the system. You can specify parameters to filter the results. The result is wrapped with PageData object that allows you to iterate over result set using pagination. See the 'Model' tab of the Response Class for more details.   Available for users with 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_audit_logs_by_entity_id_using_get(entity_type, entity_id, page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str entity_type: A string value representing the entity type. For example, 'DEVICE' (required)
        :param str entity_id: A string value representing the entity id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :param int page_size: Maximum amount of entities in a one page (required)
        :param int page: Sequence number of page starting from 0 (required)
        :param str text_search: The case insensitive 'substring' filter based on one of the next properties: entityType, entityName, userName, actionType, actionStatus.
        :param str sort_property: Property of audit log to sort by. See the 'Model' tab of the Response Class for more details. Note: entityType sort property is not defined in the AuditLog class, however, it can be used to sort audit logs by types of entities that were logged.
        :param str sort_order: Sort order. ASC (ASCENDING) or DESC (DESCENDING)
        :param int start_time: The start timestamp in milliseconds of the search time range over the AuditLog class field: 'createdTime'.
        :param int end_time: The end timestamp in milliseconds of the search time range over the AuditLog class field: 'createdTime'.
        :param str action_types: A String value representing comma-separated list of action types. This parameter is optional, but it can be used to filter results to fetch only audit logs of specific action types. For example, 'LOGIN', 'LOGOUT'. See the 'Model' tab of the Response Class for more details.
        :return: PageDataAuditLog
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_audit_logs_by_entity_id_using_get_with_http_info(entity_type, entity_id, page_size, page, **kwargs)  # noqa: E501
        else:
            (data) = self.get_audit_logs_by_entity_id_using_get_with_http_info(entity_type, entity_id, page_size, page, **kwargs)  # noqa: E501
            return data

    def get_audit_logs_by_entity_id_using_get_with_http_info(self, entity_type, entity_id, page_size, page, **kwargs):  # noqa: E501
        """Get audit logs by entity id (getAuditLogsByEntityId)  # noqa: E501

        Returns a page of audit logs related to the actions on the targeted entity. Basically, this API call is used to get the full lifecycle of some specific entity. For example to see when a device was created, updated, assigned to some customer, or even deleted from the system. You can specify parameters to filter the results. The result is wrapped with PageData object that allows you to iterate over result set using pagination. See the 'Model' tab of the Response Class for more details.   Available for users with 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_audit_logs_by_entity_id_using_get_with_http_info(entity_type, entity_id, page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str entity_type: A string value representing the entity type. For example, 'DEVICE' (required)
        :param str entity_id: A string value representing the entity id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :param int page_size: Maximum amount of entities in a one page (required)
        :param int page: Sequence number of page starting from 0 (required)
        :param str text_search: The case insensitive 'substring' filter based on one of the next properties: entityType, entityName, userName, actionType, actionStatus.
        :param str sort_property: Property of audit log to sort by. See the 'Model' tab of the Response Class for more details. Note: entityType sort property is not defined in the AuditLog class, however, it can be used to sort audit logs by types of entities that were logged.
        :param str sort_order: Sort order. ASC (ASCENDING) or DESC (DESCENDING)
        :param int start_time: The start timestamp in milliseconds of the search time range over the AuditLog class field: 'createdTime'.
        :param int end_time: The end timestamp in milliseconds of the search time range over the AuditLog class field: 'createdTime'.
        :param str action_types: A String value representing comma-separated list of action types. This parameter is optional, but it can be used to filter results to fetch only audit logs of specific action types. For example, 'LOGIN', 'LOGOUT'. See the 'Model' tab of the Response Class for more details.
        :return: PageDataAuditLog
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['entity_type', 'entity_id', 'page_size', 'page', 'text_search', 'sort_property', 'sort_order', 'start_time', 'end_time', 'action_types']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_audit_logs_by_entity_id_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'entity_type' is set
        if ('entity_type' not in params or
                params['entity_type'] is None):
            raise ValueError("Missing the required parameter `entity_type` when calling `get_audit_logs_by_entity_id_using_get`")  # noqa: E501
        # verify the required parameter 'entity_id' is set
        if ('entity_id' not in params or
                params['entity_id'] is None):
            raise ValueError("Missing the required parameter `entity_id` when calling `get_audit_logs_by_entity_id_using_get`")  # noqa: E501
        # verify the required parameter 'page_size' is set
        if ('page_size' not in params or
                params['page_size'] is None):
            raise ValueError("Missing the required parameter `page_size` when calling `get_audit_logs_by_entity_id_using_get`")  # noqa: E501
        # verify the required parameter 'page' is set
        if ('page' not in params or
                params['page'] is None):
            raise ValueError("Missing the required parameter `page` when calling `get_audit_logs_by_entity_id_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'entity_type' in params:
            path_params['entityType'] = params['entity_type']  # noqa: E501
        if 'entity_id' in params:
            path_params['entityId'] = params['entity_id']  # noqa: E501

        query_params = []
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'text_search' in params:
            query_params.append(('textSearch', params['text_search']))  # noqa: E501
        if 'sort_property' in params:
            query_params.append(('sortProperty', params['sort_property']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('sortOrder', params['sort_order']))  # noqa: E501
        if 'start_time' in params:
            query_params.append(('startTime', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('endTime', params['end_time']))  # noqa: E501
        if 'action_types' in params:
            query_params.append(('actionTypes', params['action_types']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/audit/logs/entity/{entityType}/{entityId}{?actionTypes,endTime,page,pageSize,sortOrder,sortProperty,startTime,textSearch}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageDataAuditLog',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_audit_logs_by_user_id_using_get(self, user_id, page_size, page, **kwargs):  # noqa: E501
        """Get audit logs by user id (getAuditLogsByUserId)  # noqa: E501

        Returns a page of audit logs related to the actions of targeted user. For example, RPC call to a particular device, or alarm acknowledgment for a specific device, etc. You can specify parameters to filter the results. The result is wrapped with PageData object that allows you to iterate over result set using pagination. See the 'Model' tab of the Response Class for more details.   Available for users with 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_audit_logs_by_user_id_using_get(user_id, page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: A string value representing the user id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :param int page_size: Maximum amount of entities in a one page (required)
        :param int page: Sequence number of page starting from 0 (required)
        :param str text_search: The case insensitive 'substring' filter based on one of the next properties: entityType, entityName, userName, actionType, actionStatus.
        :param str sort_property: Property of audit log to sort by. See the 'Model' tab of the Response Class for more details. Note: entityType sort property is not defined in the AuditLog class, however, it can be used to sort audit logs by types of entities that were logged.
        :param str sort_order: Sort order. ASC (ASCENDING) or DESC (DESCENDING)
        :param int start_time: The start timestamp in milliseconds of the search time range over the AuditLog class field: 'createdTime'.
        :param int end_time: The end timestamp in milliseconds of the search time range over the AuditLog class field: 'createdTime'.
        :param str action_types: A String value representing comma-separated list of action types. This parameter is optional, but it can be used to filter results to fetch only audit logs of specific action types. For example, 'LOGIN', 'LOGOUT'. See the 'Model' tab of the Response Class for more details.
        :return: PageDataAuditLog
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_audit_logs_by_user_id_using_get_with_http_info(user_id, page_size, page, **kwargs)  # noqa: E501
        else:
            (data) = self.get_audit_logs_by_user_id_using_get_with_http_info(user_id, page_size, page, **kwargs)  # noqa: E501
            return data

    def get_audit_logs_by_user_id_using_get_with_http_info(self, user_id, page_size, page, **kwargs):  # noqa: E501
        """Get audit logs by user id (getAuditLogsByUserId)  # noqa: E501

        Returns a page of audit logs related to the actions of targeted user. For example, RPC call to a particular device, or alarm acknowledgment for a specific device, etc. You can specify parameters to filter the results. The result is wrapped with PageData object that allows you to iterate over result set using pagination. See the 'Model' tab of the Response Class for more details.   Available for users with 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_audit_logs_by_user_id_using_get_with_http_info(user_id, page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: A string value representing the user id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :param int page_size: Maximum amount of entities in a one page (required)
        :param int page: Sequence number of page starting from 0 (required)
        :param str text_search: The case insensitive 'substring' filter based on one of the next properties: entityType, entityName, userName, actionType, actionStatus.
        :param str sort_property: Property of audit log to sort by. See the 'Model' tab of the Response Class for more details. Note: entityType sort property is not defined in the AuditLog class, however, it can be used to sort audit logs by types of entities that were logged.
        :param str sort_order: Sort order. ASC (ASCENDING) or DESC (DESCENDING)
        :param int start_time: The start timestamp in milliseconds of the search time range over the AuditLog class field: 'createdTime'.
        :param int end_time: The end timestamp in milliseconds of the search time range over the AuditLog class field: 'createdTime'.
        :param str action_types: A String value representing comma-separated list of action types. This parameter is optional, but it can be used to filter results to fetch only audit logs of specific action types. For example, 'LOGIN', 'LOGOUT'. See the 'Model' tab of the Response Class for more details.
        :return: PageDataAuditLog
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'page_size', 'page', 'text_search', 'sort_property', 'sort_order', 'start_time', 'end_time', 'action_types']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_audit_logs_by_user_id_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `get_audit_logs_by_user_id_using_get`")  # noqa: E501
        # verify the required parameter 'page_size' is set
        if ('page_size' not in params or
                params['page_size'] is None):
            raise ValueError("Missing the required parameter `page_size` when calling `get_audit_logs_by_user_id_using_get`")  # noqa: E501
        # verify the required parameter 'page' is set
        if ('page' not in params or
                params['page'] is None):
            raise ValueError("Missing the required parameter `page` when calling `get_audit_logs_by_user_id_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501

        query_params = []
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'text_search' in params:
            query_params.append(('textSearch', params['text_search']))  # noqa: E501
        if 'sort_property' in params:
            query_params.append(('sortProperty', params['sort_property']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('sortOrder', params['sort_order']))  # noqa: E501
        if 'start_time' in params:
            query_params.append(('startTime', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('endTime', params['end_time']))  # noqa: E501
        if 'action_types' in params:
            query_params.append(('actionTypes', params['action_types']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/audit/logs/user/{userId}{?actionTypes,endTime,page,pageSize,sortOrder,sortProperty,startTime,textSearch}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageDataAuditLog',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_audit_logs_using_get(self, page_size, page, **kwargs):  # noqa: E501
        """Get all audit logs (getAuditLogs)  # noqa: E501

        Returns a page of audit logs related to all entities in the scope of the current user's Tenant. You can specify parameters to filter the results. The result is wrapped with PageData object that allows you to iterate over result set using pagination. See the 'Model' tab of the Response Class for more details.   Available for users with 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_audit_logs_using_get(page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page_size: Maximum amount of entities in a one page (required)
        :param int page: Sequence number of page starting from 0 (required)
        :param str text_search: The case insensitive 'substring' filter based on one of the next properties: entityType, entityName, userName, actionType, actionStatus.
        :param str sort_property: Property of audit log to sort by. See the 'Model' tab of the Response Class for more details. Note: entityType sort property is not defined in the AuditLog class, however, it can be used to sort audit logs by types of entities that were logged.
        :param str sort_order: Sort order. ASC (ASCENDING) or DESC (DESCENDING)
        :param int start_time: The start timestamp in milliseconds of the search time range over the AuditLog class field: 'createdTime'.
        :param int end_time: The end timestamp in milliseconds of the search time range over the AuditLog class field: 'createdTime'.
        :param str action_types: A String value representing comma-separated list of action types. This parameter is optional, but it can be used to filter results to fetch only audit logs of specific action types. For example, 'LOGIN', 'LOGOUT'. See the 'Model' tab of the Response Class for more details.
        :return: PageDataAuditLog
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_audit_logs_using_get_with_http_info(page_size, page, **kwargs)  # noqa: E501
        else:
            (data) = self.get_audit_logs_using_get_with_http_info(page_size, page, **kwargs)  # noqa: E501
            return data

    def get_audit_logs_using_get_with_http_info(self, page_size, page, **kwargs):  # noqa: E501
        """Get all audit logs (getAuditLogs)  # noqa: E501

        Returns a page of audit logs related to all entities in the scope of the current user's Tenant. You can specify parameters to filter the results. The result is wrapped with PageData object that allows you to iterate over result set using pagination. See the 'Model' tab of the Response Class for more details.   Available for users with 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_audit_logs_using_get_with_http_info(page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page_size: Maximum amount of entities in a one page (required)
        :param int page: Sequence number of page starting from 0 (required)
        :param str text_search: The case insensitive 'substring' filter based on one of the next properties: entityType, entityName, userName, actionType, actionStatus.
        :param str sort_property: Property of audit log to sort by. See the 'Model' tab of the Response Class for more details. Note: entityType sort property is not defined in the AuditLog class, however, it can be used to sort audit logs by types of entities that were logged.
        :param str sort_order: Sort order. ASC (ASCENDING) or DESC (DESCENDING)
        :param int start_time: The start timestamp in milliseconds of the search time range over the AuditLog class field: 'createdTime'.
        :param int end_time: The end timestamp in milliseconds of the search time range over the AuditLog class field: 'createdTime'.
        :param str action_types: A String value representing comma-separated list of action types. This parameter is optional, but it can be used to filter results to fetch only audit logs of specific action types. For example, 'LOGIN', 'LOGOUT'. See the 'Model' tab of the Response Class for more details.
        :return: PageDataAuditLog
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page', 'text_search', 'sort_property', 'sort_order', 'start_time', 'end_time', 'action_types']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_audit_logs_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'page_size' is set
        if ('page_size' not in params or
                params['page_size'] is None):
            raise ValueError("Missing the required parameter `page_size` when calling `get_audit_logs_using_get`")  # noqa: E501
        # verify the required parameter 'page' is set
        if ('page' not in params or
                params['page'] is None):
            raise ValueError("Missing the required parameter `page` when calling `get_audit_logs_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'text_search' in params:
            query_params.append(('textSearch', params['text_search']))  # noqa: E501
        if 'sort_property' in params:
            query_params.append(('sortProperty', params['sort_property']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('sortOrder', params['sort_order']))  # noqa: E501
        if 'start_time' in params:
            query_params.append(('startTime', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('endTime', params['end_time']))  # noqa: E501
        if 'action_types' in params:
            query_params.append(('actionTypes', params['action_types']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/audit/logs{?actionTypes,endTime,page,pageSize,sortOrder,sortProperty,startTime,textSearch}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageDataAuditLog',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

from .default_device_profile_transport_configuration import DefaultDeviceProfileTransportConfiguration
from .json_node import JsonNode
from .page_data_edge import PageDataEdge
from .tenant_info import TenantInfo
from .admin_settings_id import AdminSettingsId
from .entity_data import EntityData
from .page_data_device import PageDataDevice
from .home_dashboard_info import HomeDashboardInfo
from .login_response import LoginResponse
from .widget_type import WidgetType
from .event_id import EventId
from .test_sms_request import TestSmsRequest
from .ota_package import OtaPackage
from .user import User
from .o_auth2_mobile_info import OAuth2MobileInfo
from .numeric_filter_predicate import NumericFilterPredicate
from .device_profile_alarm import DeviceProfileAlarm
from .ota_package_info import OtaPackageInfo
from .alarm_data import AlarmData
from .entity_id import EntityId
from .event import Event
from .complex_filter_predicate import ComplexFilterPredicate
from .edge_id import EdgeId
from .device_profile_data import DeviceProfileData
from .page_data_customer import PageDataCustomer
from .sign_up_request import SignUpRequest
from .save_ota_package_info_request import SaveOtaPackageInfoRequest
from .mqtt_device_transport_configuration import MqttDeviceTransportConfiguration
from .page_data_tb_resource_info import PageDataTbResourceInfo
from .home_dashboard import HomeDashboard
from .bulk_import_result_device import BulkImportResultDevice
from .device_search_query_filter import DeviceSearchQueryFilter
from .page_data_device_profile import PageDataDeviceProfile
from .dashboard_info import DashboardInfo
from .byte_buffer import ByteBuffer
from .entity_info import EntityInfo
from .edge import Edge
from .tenant import Tenant
from .entity_relations_query import EntityRelationsQuery
from .sms_provider_configuration import SmsProviderConfiguration
from .entity_relation_info import EntityRelationInfo
from .tenant_id import TenantId
from .component_descriptor import ComponentDescriptor
from .short_customer_info import ShortCustomerInfo
from .device_profile_info import DeviceProfileInfo
from .duration_alarm_condition_spec import DurationAlarmConditionSpec
from .o_auth2_registration_info import OAuth2RegistrationInfo
from .twilio_sms_provider_configuration import TwilioSmsProviderConfiguration
from .device_profile import DeviceProfile
from .lw_m2m_resource_observe import LwM2mResourceObserve
from .default_tenant_profile_configuration import DefaultTenantProfileConfiguration
from .check_pre_provisioned_devices_device_profile_provision_configuration import \
    CheckPreProvisionedDevicesDeviceProfileProvisionConfiguration
from .page_data_dashboard_info import PageDataDashboardInfo
from .alarm_info import AlarmInfo
from .asset import Asset
from .o_auth2_client_info import OAuth2ClientInfo
from .page_data_user import PageDataUser
from .boolean_filter_predicate import BooleanFilterPredicate
from .rule_chain_id import RuleChainId
from .admin_settings import AdminSettings
from .o_auth2_client_registration_template import OAuth2ClientRegistrationTemplate
from .rule_node import RuleNode
from .other_configuration import OtherConfiguration
from .device_data import DeviceData
from .proto_transport_payload_configuration import ProtoTransportPayloadConfiguration
from .dashboard_id import DashboardId
from .change_password_request import ChangePasswordRequest
from .tenant_profile_data import TenantProfileData
from .device import Device
from .shared_attributes_setting_snmp_communication_config import SharedAttributesSettingSnmpCommunicationConfig
from .o_auth2_custom_mapper_config import OAuth2CustomMapperConfig
from .update_message import UpdateMessage
from .power_saving_configuration import PowerSavingConfiguration
from .ota_package_id import OtaPackageId
from .error_event_filter import ErrorEventFilter
from .alarm_schedule import AlarmSchedule
from .user_id import UserId
from .asset_type_filter import AssetTypeFilter
from .statistics_event_filter import StatisticsEventFilter
from .api_usage_state_filter import ApiUsageStateFilter
from .widgets_bundle_id import WidgetsBundleId
from .atomic_integer import AtomicInteger
from .security_settings import SecuritySettings
from .event_filter import EventFilter
from .lw_m2m_object import LwM2mObject
from .edge_search_query import EdgeSearchQuery
from .o_auth2_params_info import OAuth2ParamsInfo
from .entity_view_id import EntityViewId
from .alarm_condition_filter_key import AlarmConditionFilterKey
from .device_transport_configuration import DeviceTransportConfiguration
from .alarm_condition_filter import AlarmConditionFilter
from .alarm import Alarm
from .attributes_entity_view import AttributesEntityView
from .login_request import LoginRequest
from .entity_view import EntityView
from .page_data_device_profile_info import PageDataDeviceProfileInfo
from .device_profile_provision_configuration import DeviceProfileProvisionConfiguration
from .specific_time_schedule import SpecificTimeSchedule
from .o_auth2_info import OAuth2Info
from .activate_user_request import ActivateUserRequest
from .resource import Resource
from .default_device_transport_configuration import DefaultDeviceTransportConfiguration
from .telemetry_mapping_configuration import TelemetryMappingConfiguration
from .default_device_profile_configuration import DefaultDeviceProfileConfiguration
from .any_time_schedule import AnyTimeSchedule
from .page_data_tenant import PageDataTenant
from .allow_create_new_devices_device_profile_provision_configuration import \
    AllowCreateNewDevicesDeviceProfileProvisionConfiguration
from .to_device_rpc_request_snmp_communication_config import ToDeviceRpcRequestSnmpCommunicationConfig
from .default_device_configuration import DefaultDeviceConfiguration
from .widget_type_info import WidgetTypeInfo
from .entity_name_filter import EntityNameFilter
from .tb_resource_id import TbResourceId
from .efento_coap_device_type_configuration import EfentoCoapDeviceTypeConfiguration
from .edge_event import EdgeEvent
from .page_data_rule_chain import PageDataRuleChain
from .customer_id import CustomerId
from .snmp_device_transport_configuration import SnmpDeviceTransportConfiguration
from .alarm_rule import AlarmRule
from .key_filter import KeyFilter
from .client_attributes_querying_snmp_communication_config import ClientAttributesQueryingSnmpCommunicationConfig
from .rule_chain_import_result import RuleChainImportResult
from .input_stream import InputStream
from .edge_type_filter import EdgeTypeFilter
from .object_node import ObjectNode
from .device_configuration import DeviceConfiguration
from .entity_subtype import EntitySubtype
from .entity_key import EntityKey
from .device_type_filter import DeviceTypeFilter
from .edge_search_query_filter import EdgeSearchQueryFilter
from .save_device_with_credentials_request import SaveDeviceWithCredentialsRequest
from .bulk_import_result_edge import BulkImportResultEdge
from .lwm2m_device_transport_configuration import Lwm2mDeviceTransportConfiguration
from .response_entity import ResponseEntity
from .page_data_event import PageDataEvent
from .entity_list_filter import EntityListFilter
from .deferred_result_response_entity import DeferredResultResponseEntity
from .entity_type_filter import EntityTypeFilter
from .custom_time_schedule import CustomTimeSchedule
from .snmp_communication_config import SnmpCommunicationConfig
from .dashboard import Dashboard
from .rule_chain_meta_data import RuleChainMetaData
from .bulk_import_result_asset import BulkImportResultAsset
from .edge_event_id import EdgeEventId
from .column_mapping import ColumnMapping
from .claim_request import ClaimRequest
from .widget_type_id import WidgetTypeId
from .relations_search_parameters import RelationsSearchParameters
from .thingsboard_credentials_expired_response import ThingsboardCredentialsExpiredResponse
from .o_auth2_basic_mapper_config import OAuth2BasicMapperConfig
from .page_data_widgets_bundle import PageDataWidgetsBundle
from .simple_alarm_condition_spec import SimpleAlarmConditionSpec
from .rpc import Rpc
from .widgets_bundle import WidgetsBundle
from .rpc_id import RpcId
from .page_data_entity_info import PageDataEntityInfo
from .page_data_alarm_data import PageDataAlarmData
from .default_rule_chain_create_request import DefaultRuleChainCreateRequest
from .transport_payload_type_configuration import TransportPayloadTypeConfiguration
from .ts_value import TsValue
from .telemetry_querying_snmp_communication_config import TelemetryQueryingSnmpCommunicationConfig
from .device_profile_configuration import DeviceProfileConfiguration
from .page_data_asset import PageDataAsset
from .entity_data_query import EntityDataQuery
from .entity_count_query import EntityCountQuery
from .entity_view_search_query import EntityViewSearchQuery
from .o_auth2_domain_info import OAuth2DomainInfo
from .bulk_import_request import BulkImportRequest
from .node_connection_info import NodeConnectionInfo
from .entity_data_page_link import EntityDataPageLink
from .thingsboard_error_response import ThingsboardErrorResponse
from .coap_device_transport_configuration import CoapDeviceTransportConfiguration
from .string_filter_predicate import StringFilterPredicate
from .snmp_mapping import SnmpMapping
from .mqtt_device_profile_transport_configuration import MqttDeviceProfileTransportConfiguration
from .device_credentials import DeviceCredentials
from .telemetry_entity_view import TelemetryEntityView
from .single_entity_filter import SingleEntityFilter
from .entity_view_search_query_filter import EntityViewSearchQueryFilter
from .disabled_device_profile_provision_configuration import DisabledDeviceProfileProvisionConfiguration
from .asset_search_query import AssetSearchQuery
from .entity_filter import EntityFilter
from .entity_view_type_filter import EntityViewTypeFilter
from .page_data_alarm_info import PageDataAlarmInfo
from .page_data_entity_data import PageDataEntityData
from .page_data_tenant_info import PageDataTenantInfo
from .page_data_audit_log import PageDataAuditLog
from .tenant_profile_configuration import TenantProfileConfiguration
from .customer import Customer
from .device_profile_transport_configuration import DeviceProfileTransportConfiguration
from .tb_resource_info import TbResourceInfo
from .widget_type_details import WidgetTypeDetails
from .object_attributes import ObjectAttributes
from .relation_entity_type_filter import RelationEntityTypeFilter
from .asset_search_query_filter import AssetSearchQueryFilter
from .reset_password_email_request import ResetPasswordEmailRequest
from .tenant_profile_id import TenantProfileId
from .tenant_profile import TenantProfile
from .key_filter_predicate import KeyFilterPredicate
from .o_auth2_mapper_config import OAuth2MapperConfig
from .default_coap_device_type_configuration import DefaultCoapDeviceTypeConfiguration
from .snmp_device_profile_transport_configuration import SnmpDeviceProfileTransportConfiguration
from .life_cycle_event_filter import LifeCycleEventFilter
from .relations_query_filter import RelationsQueryFilter
from .alarm_condition import AlarmCondition
from .rule_chain_data import RuleChainData
from .lw_m2m_instance import LwM2mInstance
from .repeating_alarm_condition_spec import RepeatingAlarmConditionSpec
from .page_data_tenant_profile import PageDataTenantProfile
from .custom_time_schedule_item import CustomTimeScheduleItem
from .mapping import Mapping
from .page_data_entity_view import PageDataEntityView
from .user_password_policy import UserPasswordPolicy
from .page_data_edge_event import PageDataEdgeEvent
from .device_id import DeviceId
from .aws_sns_sms_provider_configuration import AwsSnsSmsProviderConfiguration
from .lwm2m_device_profile_transport_configuration import Lwm2mDeviceProfileTransportConfiguration
from .component_descriptor_id import ComponentDescriptorId
from .entity_relation import EntityRelation
from .o_auth2_client_registration_template_id import OAuth2ClientRegistrationTemplateId
from .alarm_id import AlarmId
from .audit_log import AuditLog
from .alarm_data_page_link import AlarmDataPageLink
from .device_search_query import DeviceSearchQuery
from .debug_rule_chain_event_filter import DebugRuleChainEventFilter
from .alarm_data_query import AlarmDataQuery
from .alarm_condition_spec import AlarmConditionSpec
from .coap_device_type_configuration import CoapDeviceTypeConfiguration
from .reset_password_request import ResetPasswordRequest
from .asset_id import AssetId
from .tb_resource import TbResource
from .device_credentials_id import DeviceCredentialsId
from .rule_node_id import RuleNodeId
from .rule_chain_connection_info import RuleChainConnectionInfo
from .audit_log_id import AuditLogId
from .device_profile_id import DeviceProfileId
from .coap_device_profile_transport_configuration import CoapDeviceProfileTransportConfiguration
from .json_transport_payload_configuration import JsonTransportPayloadConfiguration
from .entity_data_sort_order import EntityDataSortOrder
from .page_data_ota_package_info import PageDataOtaPackageInfo
from .rule_chain import RuleChain
from .page_data_asset_info import PageDataAssetInfo
from .device_info import DeviceInfo
from .edge_info import EdgeInfo
from .page_data_entity_view_info import PageDataEntityViewInfo
from .page_data_edge_info import PageDataEdgeInfo
from .lw_m2_m_server_security_config_default import LwM2MServerSecurityConfigDefault
from .server_security_config import ServerSecurityConfig
from .no_sec_lw_m2_m_bootstrap_server_credential import NoSecLwM2MBootstrapServerCredential
from .rule_chain_output_labels_usage import RuleChainOutputLabelsUsage
from .asset_info import AssetInfo
from .page_data_device_info import PageDataDeviceInfo
from .entity_view_info import EntityViewInfo
from .x509_lw_m2_m_bootstrap_server_credential import X509LwM2MBootstrapServerCredential
from .lw_m2_m_bootstrap_server_credential import LwM2MBootstrapServerCredential
from .queue import Queue
from .queue_id import QueueId
from .version_load_request import VersionLoadRequest
from .version_create_request import VersionCreateRequest
from .two_fa_account_config import TwoFaAccountConfig
from .two_fa_provider_config import TwoFaProviderConfig
from .transport_payload_type_configuration import TransportPayloadTypeConfiguration
from .version_creation_result import VersionCreationResult
from .entity_version import EntityVersion
from .version_load_result import VersionLoadResult
from .entity_type_load_result import EntityTypeLoadResult
from .entity_version import EntityVersion
from .complex_version_create_request import ComplexVersionCreateRequest
from .version_load_config import VersionLoadConfig
from .single_entity_version_load_request import SingleEntityVersionLoadRequest
from .entity_type_version_load_request import EntityTypeVersionLoadRequest
from .version_create_config import VersionCreateConfig
from .single_entity_version_create_request import SingleEntityVersionCreateRequest
from .entity_type_version_create_config import EntityTypeVersionCreateConfig
from .entity_type_version_load_config import EntityTypeVersionLoadConfig
from .repository_settings import RepositorySettings
from .deferred_result_repository_settings import DeferredResultRepositorySettings
from .deferred_result_void import DeferredResultVoid
from .auto_version_create_config import AutoVersionCreateConfig
from .platform_two_fa_settings import PlatformTwoFaSettings
from .account_two_fa_settings import AccountTwoFaSettings
from .two_fa_account_config_update_request import TwoFaAccountConfigUpdateRequest
from .two_fa_provider_info import TwoFaProviderInfo
from .entity_load_error import EntityLoadError
from .alarm_comment import AlarmComment
from .alarm_comment_id import AlarmCommentId
from .alarm_comment_info import AlarmCommentInfo
from .alarm_assignee import AlarmAssignee
from .alarm_assignment_notification_rule_trigger_config import AlarmAssignmentNotificationRuleTriggerConfig
from .alarm_comment_notification_rule_trigger_config import AlarmCommentNotificationRuleTriggerConfig
from .alarm_count_query import AlarmCountQuery
from .alarm_comment_notification_rule_trigger_config import AlarmCommentNotificationRuleTriggerConfig
from .all_users_filter import AllUsersFilter
from .api_usage_limit_notification_rule_trigger_config import ApiUsageLimitNotificationRuleTriggerConfig
from .asset_profile import AssetProfile
from .asset_profile_id import AssetProfileId
from .asset_profile_info import AssetProfileInfo
from .clear_rule import ClearRule
from .comparison_ts_value import ComparisonTsValue
from .customer_users_filter import CustomerUsersFilter
from .delivery_method_notification_template import DeliveryMethodNotificationTemplate
from .device_activity_notification_rule_trigger_config import DeviceActivityNotificationRuleTriggerConfig
from .edge_install_instructions import EdgeInstallInstructions
from .email_delivery_method_notification_template import EmailDeliveryMethodNotificationTemplate
from .entities_limit_notification_rule_trigger_config import EntitiesLimitNotificationRuleTriggerConfig
from .entity_action_notification_rule_trigger_config import EntityActionNotificationRuleTriggerConfig
from .escalated_notification_rule_recipients_config import EscalatedNotificationRuleRecipientsConfig
from .event_info import EventInfo
from .features_info import FeaturesInfo
from .last_visited_dashboard_info import LastVisitedDashboardInfo
from .new_platform_version_notification_rule_trigger_config import NewPlatformVersionNotificationRuleTriggerConfig
from .notification import Notification
from .notification_delivery_method_config import NotificationDeliveryMethodConfig
from .notification_id import NotificationId
from .notification_info import NotificationInfo
from .notification_request import NotificationRequest
from .notification_request_config import NotificationRequestConfig
from .notification_request_id import NotificationRequestId
from .notification_request_info import NotificationRequestInfo
from .notification_request_preview import NotificationRequestPreview
from .notification_request_stats import NotificationRequestStats
from .notification_rule import NotificationRule
from .notification_rule_config import NotificationRuleConfig
from .notification_rule_id import NotificationRuleId
from .notification_rule_info import NotificationRuleInfo
from .notification_rule_recipients_config import NotificationRuleRecipientsConfig
from .notification_rule_trigger_config import NotificationRuleTriggerConfig
from .notification_settings import NotificationSettings
from .notification_target import NotificationTarget
from .notification_target_config import NotificationTargetConfig
from .notification_target_id import NotificationTargetId
from .notification_template import NotificationTemplate
from .notification_template_config import NotificationTemplateConfig
from .notification_template_id import NotificationTemplateId
from .originator_entity_owner_users_filter import OriginatorEntityOwnerUsersFilter
from .page_data_alarm_comment_info import PageDataAlarmCommentInfo
from .page_data_asset_profile import PageDataAssetProfile
from .page_data_asset_profile_info import PageDataAssetProfileInfo
from .page_data_event_info import PageDataEventInfo
from .page_data_notification import PageDataNotification
from .page_data_notification_request_info import PageDataNotificationRequestInfo
from .page_data_notification_rule_info import PageDataNotificationRuleInfo
from .page_data_notification_target import PageDataNotificationTarget
from .page_data_notification_template import PageDataNotificationTemplate
from .page_data_user_email_info import PageDataUserEmailInfo
from .platform_users_notification_target_config import PlatformUsersNotificationTargetConfig
from .repository_settings_info import RepositorySettingsInfo
from .rule_chain_debug_event_filter import RuleChainDebugEventFilter
from .rule_engine_component_lifecycle_event_notification_rule_trigger_config import RuleEngineComponentLifecycleEventNotificationRuleTriggerConfig # noqa
from .slack_conversation import SlackConversation
from .slack_delivery_method_notification_template import SlackDeliveryMethodNotificationTemplate
from .slack_notification_delivery_method_config import SlackNotificationDeliveryMethodConfig
from .slack_notification_target_config import SlackNotificationTargetConfig
from .sms_delivery_method_notification_template import SmsDeliveryMethodNotificationTemplate
from .starred_dashboard_info import StarredDashboardInfo
from .system_administrators_filter import SystemAdministratorsFilter
from .system_info import SystemInfo
from .system_info_data import SystemInfoData
from .tenant_administrators_filter import TenantAdministratorsFilter
from .usage_info import UsageInfo
from .user_dashboards_info import UserDashboardsInfo
from .user_email_info import UserEmailInfo
from .user_list_filter import UserListFilter
from .users_filter import UsersFilter
from .web_delivery_method_notification_template import WebDeliveryMethodNotificationTemplate
from .x509_certificate_chain_provision_configuration import X509CertificateChainProvisionConfiguration
from .user_notification_settings import UserNotificationSettings
from .button import Button
from .microsoft_teams_delivery_method_notification_template import MicrosoftTeamsDeliveryMethodNotificationTemplate
from .microsoft_teams_notification_target_config import MicrosoftTeamsNotificationTargetConfig
from .notification_pref import NotificationPref
from .page_data_entity_subtype import PageDataEntitySubtype
from .page_data_widget_type_info import PageDataWidgetTypeInfo
from .rate_limits_notification_rule_trigger_config import RateLimitsNotificationRuleTriggerConfig
from .to_server_rpc_request_snmp_communication_config import ToServerRpcRequestSnmpCommunicationConfig
from .user_notification_settings import UserNotificationSettings
from .widget_type_export_data import WidgetTypeExportData
from .api_image_body import ApiImageBody
from .byte_array_resource import ByteArrayResource
from .edge_instructions import EdgeInstructions
from .image_export_data import ImageExportData
from .tb_image_delete_result import TbImageDeleteResult
from .type_key_body import TypeKeyBody
from .edge_communication_failure_notification_rule_trigger_config import EdgeCommunicationFailureNotificationRuleTriggerConfig # noqa
from .edge_connection_notification_rule_trigger_config import EdgeConnectionNotificationRuleTriggerConfig
from .mobile_app_delivery_method_notification_template import MobileAppDeliveryMethodNotificationTemplate
from .mobile_app_notification_delivery_method_config import MobileAppNotificationDeliveryMethodConfig
from .mobile_session_info import MobileSessionInfo
from .android_config import AndroidConfig
from .auto_commit_settings import AutoCommitSettings
from .bulk_import_result_asset_created import BulkImportResultAssetCreated
from .config_submit_body import ConfigSubmitBody
from .debug_converter_event_filter import DebugConverterEventFilter
from .debug_integration_event_filter import DebugIntegrationEventFilter
from .dynamic_value_double import DynamicValueDouble
from .dynamic_value_boolean import DynamicValueBoolean
from .dynamic_value_integer import DynamicValueInteger
from .dynamic_value_long import DynamicValueLong
from .dynamic_value_string import DynamicValueString
from .entity_export_data_object import EntityExportDataObject
from .filter_predicate_value_boolean import FilterPredicateValueBoolean
from .filter_predicate_value_double import FilterPredicateValueDouble
from .filter_predicate_value_integer import FilterPredicateValueInteger
from .filter_predicate_value_long import FilterPredicateValueLong
from .filter_predicate_value_string import FilterPredicateValueString
from .has_id_object import HasIdObject
from .inline_response200 import InlineResponse200
from .ios_config import IosConfig
from .lw_m2m_version import LwM2mVersion
from .mobile_app_settings import MobileAppSettings
from .mobile_app_settings_id import MobileAppSettingsId
from .one_of_alarm_condition_filter_predicate import OneOfAlarmConditionFilterPredicate
from .one_of_alarm_condition_spec import OneOfAlarmConditionSpec
from .one_of_alarm_count_query_entity_filter import OneOfAlarmCountQueryEntityFilter
from .one_of_alarm_data_query_entity_filter import OneOfAlarmDataQueryEntityFilter
from .one_of_alarm_rule_schedule import OneOfAlarmRuleSchedule
from .one_of_device_data_transport_configuration import OneOfDeviceDataTransportConfiguration
from .one_of_device_data_configuration import OneOfDeviceDataConfiguration
from .one_of_device_profile_data_configuration import OneOfDeviceProfileDataConfiguration
from .one_of_device_profile_data_provision_configuration import OneOfDeviceProfileDataProvisionConfiguration
from .one_of_device_profile_data_transport_configuration import OneOfDeviceProfileDataTransportConfiguration
from .one_of_entity_data_diff_current_version import OneOfEntityDataDiffCurrentVersion
from .one_of_entity_data_diff_other_version import OneOfEntityDataDiffOtherVersion
from .one_of_entity_data_query_entity_filter import OneOfEntityDataQueryEntityFilter
from .one_of_entity_count_query_entity_filter import OneOfEntityCountQueryEntityFilter
from .one_of_key_filter_predicate import OneOfKeyFilterPredicate
from .one_of_notification_rule_info_recipients_config import OneOfNotificationRuleInfoRecipientsConfig
from .one_of_notification_rule_info_trigger_config import OneOfNotificationRuleInfoTriggerConfig
from .one_of_notification_rule_recipients_config import OneOfNotificationRuleRecipientsConfig
from .one_of_notification_rule_trigger_config import OneOfNotificationRuleTriggerConfig
from .one_of_notification_target_configuration import OneOfNotificationTargetConfiguration
from .one_of_platform_two_fa_settings_providers_items import OneOfPlatformTwoFaSettingsProvidersItems
from .one_of_tenant_profile_data_configuration import OneOfTenantProfileDataConfiguration
from .one_of_test_sms_request_provider_configuration import OneOfTestSmsRequestProviderConfiguration
from .ota_package_data import OtaPackageData
from .page_data_queue_stats import PageDataQueueStats
from .qr_code_config import QRCodeConfig
from .queue_stats import QueueStats
from .queue_stats_id import QueueStatsId
from .vc_version_body import VcVersionBody
from .vc_entity_body import VcEntityBody
from .version import Version
from .entity_id_clearstart_timeend_time_body import EntityIdClearstartTimeendTimeBody
from .jwt_pair import JwtPair
from .jwt_settings import JwtSettings
from .alarm_notification_rule_trigger_config import AlarmNotificationRuleTriggerConfig



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.7.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from tb_rest_client.api_client import ApiClient


class QueueStatsControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_queue_stats_by_id(self, queue_stats_id, **kwargs):  # noqa: E501
        """Get Queue stats entity by id (getQueueStatsById)  # noqa: E501

        Fetch the Queue stats object based on the provided Queue stats id.   Available for users with 'SYS_ADMIN' or 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_queue_stats_by_id(queue_stats_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str queue_stats_id: A string value representing the queue stats id. For example, '687f294c-42b6-435a-983c-b7beff2784f9' (required)
        :return: QueueStats
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_queue_stats_by_id_with_http_info(queue_stats_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_queue_stats_by_id_with_http_info(queue_stats_id, **kwargs)  # noqa: E501
            return data

    def get_queue_stats_by_id_with_http_info(self, queue_stats_id, **kwargs):  # noqa: E501
        """Get Queue stats entity by id (getQueueStatsById)  # noqa: E501

        Fetch the Queue stats object based on the provided Queue stats id.   Available for users with 'SYS_ADMIN' or 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_queue_stats_by_id_with_http_info(queue_stats_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str queue_stats_id: A string value representing the queue stats id. For example, '687f294c-42b6-435a-983c-b7beff2784f9' (required)
        :return: QueueStats
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['queue_stats_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_queue_stats_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'queue_stats_id' is set
        if ('queue_stats_id' not in params or
                params['queue_stats_id'] is None):
            raise ValueError("Missing the required parameter `queue_stats_id` when calling `get_queue_stats_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'queue_stats_id' in params:
            path_params['queueStatsId'] = params['queue_stats_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/queueStats/{queueStatsId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QueueStats',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_queue_stats_by_ids(self, queue_stats_ids, **kwargs):  # noqa: E501
        """Get QueueStats By Ids (getQueueStatsByIds)  # noqa: E501

        Fetch the Queue stats objects based on the provided ids.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_queue_stats_by_ids(queue_stats_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str queue_stats_ids: A list of queue stats ids, separated by comma ',' (required)
        :return: list[QueueStats]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_queue_stats_by_ids_with_http_info(queue_stats_ids, **kwargs)  # noqa: E501
        else:
            (data) = self.get_queue_stats_by_ids_with_http_info(queue_stats_ids, **kwargs)  # noqa: E501
            return data

    def get_queue_stats_by_ids_with_http_info(self, queue_stats_ids, **kwargs):  # noqa: E501
        """Get QueueStats By Ids (getQueueStatsByIds)  # noqa: E501

        Fetch the Queue stats objects based on the provided ids.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_queue_stats_by_ids_with_http_info(queue_stats_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str queue_stats_ids: A list of queue stats ids, separated by comma ',' (required)
        :return: list[QueueStats]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['queue_stats_ids']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_queue_stats_by_ids" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'queue_stats_ids' is set
        if ('queue_stats_ids' not in params or
                params['queue_stats_ids'] is None):
            raise ValueError("Missing the required parameter `queue_stats_ids` when calling `get_queue_stats_by_ids`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'queue_stats_ids' in params:
            query_params.append(('queueStatsIds', params['queue_stats_ids']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/queueStats{?queueStatsIds}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[QueueStats]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_tenant_queue_stats(self, page_size, page, **kwargs):  # noqa: E501
        """Get Queue Stats entities (getTenantQueueStats)  # noqa: E501

        Returns a page of queue stats objects that are designed to collect queue statistics for every service. You can specify parameters to filter the results. The result is wrapped with PageData object that allows you to iterate over result set using pagination. See the 'Model' tab of the Response Class for more details.   Available for users with 'SYS_ADMIN' or 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_tenant_queue_stats(page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page_size: Maximum amount of entities in a one page (required)
        :param int page: Sequence number of page starting from 0 (required)
        :param str text_search: The case insensitive 'substring' filter based on the queue name or service id.
        :param str sort_property: Property of entity to sort by
        :param str sort_order: Sort order. ASC (ASCENDING) or DESC (DESCENDING)
        :return: PageDataQueueStats
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_tenant_queue_stats_with_http_info(page_size, page, **kwargs)  # noqa: E501
        else:
            (data) = self.get_tenant_queue_stats_with_http_info(page_size, page, **kwargs)  # noqa: E501
            return data

    def get_tenant_queue_stats_with_http_info(self, page_size, page, **kwargs):  # noqa: E501
        """Get Queue Stats entities (getTenantQueueStats)  # noqa: E501

        Returns a page of queue stats objects that are designed to collect queue statistics for every service. You can specify parameters to filter the results. The result is wrapped with PageData object that allows you to iterate over result set using pagination. See the 'Model' tab of the Response Class for more details.   Available for users with 'SYS_ADMIN' or 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_tenant_queue_stats_with_http_info(page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page_size: Maximum amount of entities in a one page (required)
        :param int page: Sequence number of page starting from 0 (required)
        :param str text_search: The case insensitive 'substring' filter based on the queue name or service id.
        :param str sort_property: Property of entity to sort by
        :param str sort_order: Sort order. ASC (ASCENDING) or DESC (DESCENDING)
        :return: PageDataQueueStats
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page', 'text_search', 'sort_property', 'sort_order']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_tenant_queue_stats" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'page_size' is set
        if ('page_size' not in params or
                params['page_size'] is None):
            raise ValueError("Missing the required parameter `page_size` when calling `get_tenant_queue_stats`")  # noqa: E501
        # verify the required parameter 'page' is set
        if ('page' not in params or
                params['page'] is None):
            raise ValueError("Missing the required parameter `page` when calling `get_tenant_queue_stats`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'text_search' in params:
            query_params.append(('textSearch', params['text_search']))  # noqa: E501
        if 'sort_property' in params:
            query_params.append(('sortProperty', params['sort_property']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('sortOrder', params['sort_order']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/queueStats{?pageSize,page,textSearch,sortProperty,sortOrder}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageDataQueueStats',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.7.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class AlarmCountQuery(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'start_ts': 'int',
        'end_ts': 'int',
        'time_window': 'int',
        'type_list': 'list[str]',
        'status_list': 'list[str]',
        'severity_list': 'list[str]',
        'search_propagated_alarms': 'bool',
        'assignee_id': 'UserId',
        'entity_filter': 'OneOfAlarmCountQueryEntityFilter',
        'key_filters': 'list[KeyFilter]'
    }

    attribute_map = {
        'start_ts': 'startTs',
        'end_ts': 'endTs',
        'time_window': 'timeWindow',
        'type_list': 'typeList',
        'status_list': 'statusList',
        'severity_list': 'severityList',
        'search_propagated_alarms': 'searchPropagatedAlarms',
        'assignee_id': 'assigneeId',
        'entity_filter': 'entityFilter',
        'key_filters': 'keyFilters'
    }

    def __init__(self, start_ts=None, end_ts=None, time_window=None, type_list=None, status_list=None, severity_list=None, search_propagated_alarms=None, assignee_id=None, entity_filter=None, key_filters=None):  # noqa: E501
        """AlarmCountQuery - a model defined in Swagger"""  # noqa: E501
        self._start_ts = None
        self._end_ts = None
        self._time_window = None
        self._type_list = None
        self._status_list = None
        self._severity_list = None
        self._search_propagated_alarms = None
        self._assignee_id = None
        self._entity_filter = None
        self._key_filters = None
        self.discriminator = None
        if start_ts is not None:
            self.start_ts = start_ts
        if end_ts is not None:
            self.end_ts = end_ts
        if time_window is not None:
            self.time_window = time_window
        if type_list is not None:
            self.type_list = type_list
        if status_list is not None:
            self.status_list = status_list
        if severity_list is not None:
            self.severity_list = severity_list
        if search_propagated_alarms is not None:
            self.search_propagated_alarms = search_propagated_alarms
        if assignee_id is not None:
            self.assignee_id = assignee_id
        if entity_filter is not None:
            self.entity_filter = entity_filter
        if key_filters is not None:
            self.key_filters = key_filters

    @property
    def start_ts(self):
        """Gets the start_ts of this AlarmCountQuery.  # noqa: E501


        :return: The start_ts of this AlarmCountQuery.  # noqa: E501
        :rtype: int
        """
        return self._start_ts

    @start_ts.setter
    def start_ts(self, start_ts):
        """Sets the start_ts of this AlarmCountQuery.


        :param start_ts: The start_ts of this AlarmCountQuery.  # noqa: E501
        :type: int
        """

        self._start_ts = start_ts

    @property
    def end_ts(self):
        """Gets the end_ts of this AlarmCountQuery.  # noqa: E501


        :return: The end_ts of this AlarmCountQuery.  # noqa: E501
        :rtype: int
        """
        return self._end_ts

    @end_ts.setter
    def end_ts(self, end_ts):
        """Sets the end_ts of this AlarmCountQuery.


        :param end_ts: The end_ts of this AlarmCountQuery.  # noqa: E501
        :type: int
        """

        self._end_ts = end_ts

    @property
    def time_window(self):
        """Gets the time_window of this AlarmCountQuery.  # noqa: E501


        :return: The time_window of this AlarmCountQuery.  # noqa: E501
        :rtype: int
        """
        return self._time_window

    @time_window.setter
    def time_window(self, time_window):
        """Sets the time_window of this AlarmCountQuery.


        :param time_window: The time_window of this AlarmCountQuery.  # noqa: E501
        :type: int
        """

        self._time_window = time_window

    @property
    def type_list(self):
        """Gets the type_list of this AlarmCountQuery.  # noqa: E501


        :return: The type_list of this AlarmCountQuery.  # noqa: E501
        :rtype: list[str]
        """
        return self._type_list

    @type_list.setter
    def type_list(self, type_list):
        """Sets the type_list of this AlarmCountQuery.


        :param type_list: The type_list of this AlarmCountQuery.  # noqa: E501
        :type: list[str]
        """

        self._type_list = type_list

    @property
    def status_list(self):
        """Gets the status_list of this AlarmCountQuery.  # noqa: E501


        :return: The status_list of this AlarmCountQuery.  # noqa: E501
        :rtype: list[str]
        """
        return self._status_list

    @status_list.setter
    def status_list(self, status_list):
        """Sets the status_list of this AlarmCountQuery.


        :param status_list: The status_list of this AlarmCountQuery.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["ANY", "ACTIVE", "CLEARED", "ACK", "UNACK"]  # noqa: E501
        if not set(status_list).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `status_list` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(status_list) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._status_list = status_list

    @property
    def severity_list(self):
        """Gets the severity_list of this AlarmCountQuery.  # noqa: E501


        :return: The severity_list of this AlarmCountQuery.  # noqa: E501
        :rtype: list[str]
        """
        return self._severity_list

    @severity_list.setter
    def severity_list(self, severity_list):
        """Sets the severity_list of this AlarmCountQuery.


        :param severity_list: The severity_list of this AlarmCountQuery.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["CRITICAL", "MAJOR", "MINOR", "WARNING", "INDETERMINATE"]  # noqa: E501
        if not set(severity_list).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `severity_list` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(severity_list) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._severity_list = severity_list

    @property
    def search_propagated_alarms(self):
        """Gets the search_propagated_alarms of this AlarmCountQuery.  # noqa: E501


        :return: The search_propagated_alarms of this AlarmCountQuery.  # noqa: E501
        :rtype: bool
        """
        return self._search_propagated_alarms

    @search_propagated_alarms.setter
    def search_propagated_alarms(self, search_propagated_alarms):
        """Sets the search_propagated_alarms of this AlarmCountQuery.


        :param search_propagated_alarms: The search_propagated_alarms of this AlarmCountQuery.  # noqa: E501
        :type: bool
        """

        self._search_propagated_alarms = search_propagated_alarms

    @property
    def assignee_id(self):
        """Gets the assignee_id of this AlarmCountQuery.  # noqa: E501


        :return: The assignee_id of this AlarmCountQuery.  # noqa: E501
        :rtype: UserId
        """
        return self._assignee_id

    @assignee_id.setter
    def assignee_id(self, assignee_id):
        """Sets the assignee_id of this AlarmCountQuery.


        :param assignee_id: The assignee_id of this AlarmCountQuery.  # noqa: E501
        :type: UserId
        """

        self._assignee_id = assignee_id

    @property
    def entity_filter(self):
        """Gets the entity_filter of this AlarmCountQuery.  # noqa: E501


        :return: The entity_filter of this AlarmCountQuery.  # noqa: E501
        :rtype: OneOfAlarmCountQueryEntityFilter
        """
        return self._entity_filter

    @entity_filter.setter
    def entity_filter(self, entity_filter):
        """Sets the entity_filter of this AlarmCountQuery.


        :param entity_filter: The entity_filter of this AlarmCountQuery.  # noqa: E501
        :type: OneOfAlarmCountQueryEntityFilter
        """

        self._entity_filter = entity_filter

    @property
    def key_filters(self):
        """Gets the key_filters of this AlarmCountQuery.  # noqa: E501


        :return: The key_filters of this AlarmCountQuery.  # noqa: E501
        :rtype: list[KeyFilter]
        """
        return self._key_filters

    @key_filters.setter
    def key_filters(self, key_filters):
        """Sets the key_filters of this AlarmCountQuery.


        :param key_filters: The key_filters of this AlarmCountQuery.  # noqa: E501
        :type: list[KeyFilter]
        """

        self._key_filters = key_filters

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AlarmCountQuery, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AlarmCountQuery):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import logging
from argparse import ArgumentParser
from random import choice
from string import hexdigits
from time import sleep

from tb_rest_client.models.models_pe import EntityVersion, EntityTypeVersionCreateConfig, ComplexVersionCreateRequest
from tb_rest_client.rest import ApiException
from tb_rest_client.rest_client_pe import RestClientPE

logging.basicConfig(level=logging.DEBUG,
                    format='%(asctime)s - %(levelname)s - %(module)s - %(lineno)d - %(message)s',
                    datefmt='%Y-%m-%d %H:%M:%S')

available_entity_types_for_save = ['CUSTOMER', 'ASSET', 'RULE_CHAIN', 'DASHBOARD', 'DEVICE_PROFILE', 'DEVICE',
                                   'ENTITY_VIEW', 'WIDGETS_BUNDLE', 'CONVERTER', 'INTEGRATION', 'ROLE', 'USER',
                                   'ENTITY_GROUP']


def main(user: str, password: str, host: str = "localhost", port: int = 80, branch: str = "main",
         save_attributes: bool = True, save_credentials: bool = True, save_relations: bool = True,
         save_group_entities: bool = True, save_permissions: bool = True, sync_strategy: str = "MERGE",
         version_name=None):

    url = host
    if "https://" not in host:
        if "http://" not in host:
            if port != 443:
                url = "http://" + host + ":" + str(port)
            else:
                url = "https://" + host + ":443"

    with RestClientPE(base_url=url) as rest_client:
        try:
            # Auth with credentials
            logging.info("Logging in...")
            rest_client.login(username=user, password=password)
            logging.info("Logged in.")

            if version_name is None:
                version_name = "".join(choice(hexdigits) for _ in range(5))

            request_config_parameters = {
                "all_entities": True,
                "entity_ids": None,
                "save_attributes": save_attributes,
                "save_credentials": save_credentials,
                "save_relations": save_relations,
                "save_group_entities": save_group_entities,
                "save_permissions": save_permissions,
                "sync_strategy": sync_strategy.upper()
            }

            # Create version create request for device

            entity_type_version_create_request_config = EntityTypeVersionCreateConfig(**request_config_parameters)
            configs_for_entity_types = {entity_type: entity_type_version_create_request_config for entity_type in
                                        available_entity_types_for_save}
            vcr = ComplexVersionCreateRequest(branch, configs_for_entity_types,
                                              request_config_parameters['sync_strategy'], "COMPLEX",
                                              version_name)

            version_request_id = rest_client.save_entities_version(vcr)
            logging.info("Version creation request id: %r", version_request_id)

            # Get the result for request_status

            request_status = rest_client.get_version_create_request_status(version_request_id)
            while not isinstance(request_status, EntityVersion) and not request_status.done:
                request_status = rest_client.get_version_create_request_status(version_request_id)
                sleep(1)

            logging.info("Version with name %s creation result: \n %r", version_name, request_status)

        except ApiException as e:
            logging.exception(e)


if __name__ == '__main__':
    parser = ArgumentParser(description="""
    This script creates new version of all available entities and saves it to version control system.""")
    parser.add_argument("-U", "--user", help="User email to login into ThingsBoard", required=True)
    parser.add_argument("-P", "--password", help="User password to login into ThingsBoard", required=True)

    parser.add_argument("-H", "--host", help="ThingsBoard host", default="localhost")
    parser.add_argument("-p", "--port", help="ThingsBoard port", type=int, default=80)

    parser.add_argument("-B", "--branch", help="Branch", default="main")
    parser.add_argument("-N", "--version_name",
                        help="Version name (Commit name), by default 5 symbols string will be generated.")

    parser.add_argument("--save_attributes", help="Save attributes for entities", type=bool, default=True)
    parser.add_argument("--save_credentials", help="Save credentials for devices and users", type=bool, default=True)
    parser.add_argument("--save_relations", help="Save relations for entities", type=bool, default=True)
    parser.add_argument("--save_group_entities", help="Save entity groups for entities", type=bool, default=True)
    parser.add_argument("--save_permissions", help="Save permissions for users", type=bool, default=True)
    parser.add_argument("--sync_strategy", help="Sync strategy can be MERGE or OVERWRITE", default="MERGE")

    args = parser.parse_args()
    main(**args.__dict__)
